@@ -16,7 +16,7 @@ from keypartx.basemodes.avn_base import nlp
 
 
 ## -- avnn edges-- ##
-def avnn(line_en,by_review = False,other_edges = True,verbose_text = False,only_otherNouns = False, only_opiAV = True, nncompound = True, opi_verbs = opi_verbs ,neg_words = neg_words, nounDEL =nounDEL, adjDEL = adjDEL,facility=False,faciNN = False, emojis = True, emojiINtext = False,  check_spell = True,back_again = True,myBA = False,myBAverb = False):
+def avnn(line_en,by_review = False,other_edges = True,verbose_text = False,only_otherNouns = False, only_opiAV = True, nncompound = True, opi_verbs = opi_verbs ,neg_words = neg_words, nounDEL =nounDEL, adjDEL = adjDEL,facility=False,faciNN = False, emojis = True, emojiINtext = False,  check_spell = True,back_again = False,myBA = False,myBAverb = False):
     """
     line_en:  string of english review 
     include_otherEdge: greedy edges of the unmatched adj, verb, noun 
@@ -27,8 +27,8 @@ def avnn(line_en,by_review = False,other_edges = True,verbose_text = False,only_
     faciNN: if true, add facility noun to all NN edges, otherwise facility only add to AV2N in the otherEdges other than facilty-N in the matched AV2N to form greedy NN 
     emojis: if true, it will return a list of emojis in text, otherwise dropped 
     emojiINtext: if ture, it will tranform emojis as noun words as part of the whole text # I love 🎅 --- I love santa_claus 
-    back_again:  visit, come, go, travel, be and others verbs 
-    myBAverb: if false means all verbs other you can you own abverbs ['visit', 'come','go', 'travel', 'be'] to add 'back','again'
+    back_again:  if ture default verb + back , again phrase otherwise you can add your own verb(list myBaverb) and adverb(myBA), if alse then no verb phrase
+    myBAverb: if false means all verbs other you can add your own abverbs e.g. ['visit', 'come','go', 'travel', 'be'] to add 'back','again'
     myBA: if false ['back','again']
     """
     time_start = time.time()
@@ -95,7 +95,7 @@ def avnn(line_en,by_review = False,other_edges = True,verbose_text = False,only_
                     new_node_adjs.extend(new_node_adjs0)
                     emojis1.extend(emojis0)
     except:
-        print('---sth wrong ---')
+        raise
     
     print('processing time:', time.time()-time_start)
     print('length of sentences:',sent_i)
@@ -104,7 +104,7 @@ def avnn(line_en,by_review = False,other_edges = True,verbose_text = False,only_
 
   
 # comments_en list 
-def avnn2(comments_en,by_review = False,other_edges = True,verbose_text = False,only_otherNouns = False, only_opiAV = True, nncompound = True, opi_verbs = opi_verbs ,neg_words = neg_words, nounDEL =nounDEL, adjDEL = adjDEL,facility=False,faciNN = False, emojis = True, emojiINtext = False, check_spell = True,back_again = True,myBA = False,myBAverb = False):
+def avnn2(comments_en,by_review = False,other_edges = True,verbose_text = False,only_otherNouns = False, only_opiAV = True, nncompound = True, opi_verbs = opi_verbs ,neg_words = neg_words, nounDEL =nounDEL, adjDEL = adjDEL,facility=False,faciNN = False, emojis = True, emojiINtext = False, check_spell = True,back_again = False,myBA = False,myBAverb = False):
     """
     comments_en:  list of text 
     include_otherEdge: greedy edges of the unmatched adj, verb, noun 
@@ -115,8 +115,8 @@ def avnn2(comments_en,by_review = False,other_edges = True,verbose_text = False,
     faciNN: add facility noun to NN edges, otherwise facility only add to AV2N in the otherEdges other than facilty-N in the matched AV2N to form greedy NN 
     emojis: if true, it will return a list of emojis in text, otherwise dropped 
     emojiINtext: if ture, it will tranform emojis as noun words as part of the whole text # I love 🎅 --- I love santa_claus 
-    back_again:  visit, come, go, travel, be and others verbs 
-    myBAverb: if false means all verbs other you can you own abverbs ['visit', 'come','go', 'travel', 'be'] to add 'back','again'
+    back_again:  if ture default verb + back , again phrase otherwise you can add your own verb(list myBaverb) and adverb(myBA), if alse then no verb phrase
+    myBAverb: if false means all verbs other you can add your own abverbs e.g. ['visit', 'come','go', 'travel', 'be'] to add 'back','again'
     myBA: if false ['back','again']
     """
     time_start = time.time()
@@ -185,7 +185,7 @@ def avnn2(comments_en,by_review = False,other_edges = True,verbose_text = False,
                         new_node_adjs.extend(new_node_adjs0)
                         emojis1.extend(emojis0)
         except:
-            print('---sth wrong ---')
+            raise
         
     print('processing time:', time.time()-time_start)
     print('length of reviews:',line_i)
