@@ -258,7 +258,7 @@ class unit2sent:
 
 
 
-def units2DF(colorGrayDF,includeGray = True, ncR=0.01, vdR = .01, adR =.01,ndR =.01 , iPOS = 5 ):
+def units2DF(colorGrayDF,includeGray = True, ncR=0.01, vdR = .01, adR =.01,ndR =.01 , iPOS = 5,centrality = 'degree'):
     """ 
     includeGray: include gray node and edge
     ncR: core noun degree/ core nouns degree sum
@@ -266,6 +266,7 @@ def units2DF(colorGrayDF,includeGray = True, ncR=0.01, vdR = .01, adR =.01,ndR =
     adR: adjective to core noun edge weight/ adjectives to core noun edges sum
     ndR: noun to core noun edge weight/ nouns to core noun edges sum
     iPOS: choose first 5 knVerbs, knAdjs, knNouns 
+    centrality:'degree','closeness', 'betweenness'
     """
     unitDFs = []
     for i in range(len(colorGrayDF)): 
@@ -328,6 +329,40 @@ def units2DF(colorGrayDF,includeGray = True, ncR=0.01, vdR = .01, adR =.01,ndR =
 
         
         unitDF = pd.DataFrame({'community':i, 'keyNouns': keyNouns,'keyNounsD':keyNounFreqs,'keyNounColors': nodeColors,'knVERBs':knVERBs,'knADJs':knADJs,'knNOUNs':knNOUNs,'knWedges':knWedges})
+        # add centrality coloumn to key nouns 
+        knWedges2 =  unitDF.knWedges.to_list()
+        knWedges3 = []
+        for xs in knWedges2:
+          for x in xs:
+            knWedges3.append(x)
+        knWedges4 = set(knWedges3)
+        Gd = nx.DiGraph() 
+        Gd.add_weighted_edges_from(knWedges4)
+        if centrality == 'degree':
+          de_center = nx.degree_centrality(Gd)
+          center_name = "degree_centrality"
+        elif centrality =='closeness':
+          de_center = nx.closeness_centrality(Gd)
+          center_name ="closeness_centrality"
+        elif centrality =="betweenness":
+          de_center =  nx.betweenness_centrality(Gd)
+          center_name = "betweenness_centrality"
+        keynouns = unitDF.keyNouns.to_list()
+        key_value = {}
+        for key,value in de_center.items():
+          key1 = re.sub(r'[2][a-zA-Z]{3}',"",key) 
+          key_value.update({key1:value})
+
+        values = []
+        for kn in keynouns:
+          kn1 = re.sub("\((.*?)\)","",kn) # any words between two notations ()
+          value = key_value[kn1]
+          values.append(value)
+        unitDF[center_name] = values
+
+
+        
+        
         unitDFs.append(unitDF)
     unitDF_all = pd.concat(unitDFs)
     unitDF_all['keyNounsD'] = unitDF_all['keyNounsD'].astype('Int64')
